@@ -1,6 +1,6 @@
 package List::Objects::WithUtils::Role::Array;
 {
-  $List::Objects::WithUtils::Role::Array::VERSION = '1.002002';
+  $List::Objects::WithUtils::Role::Array::VERSION = '1.003000';
 }
 use strictures 1;
 
@@ -12,6 +12,23 @@ use List::UtilsBy ();
 
 use Scalar::Util 'blessed', 'reftype';
 
+=pod
+
+=for Pod::Coverage ARRAY_TYPE blessed_or_pkg
+
+=cut
+
+sub ARRAY_TYPE () { 'List::Objects::WithUtils::Array' }
+my $_required;
+sub blessed_or_pkg {
+  my $pkg; ($pkg = blessed $_[0]) ? return $pkg
+    : $_required ? 
+      return ARRAY_TYPE
+    : eval( 'require ' . ARRAY_TYPE . ';1' ) and $_required++, 
+      return ARRAY_TYPE
+}
+
+
 use Role::Tiny;
 
 sub new {
@@ -19,11 +36,11 @@ sub new {
 }
 
 sub copy {
-  bless [ @{ $_[0] } ], blessed($_[0])
+  bless [ @{ $_[0] } ], blessed_or_pkg($_[0])
 }
 
 sub count { CORE::scalar @{ $_[0] } }
-{ no warnings 'once'; *scalar = *count; }
+{ no warnings 'once'; *scalar = *count; *export = *all; }
 
 sub is_empty { CORE::scalar @{ $_[0] } ? 0 : 1 }
 
@@ -35,7 +52,7 @@ sub head {
   wantarray ?
     ( 
       $_[0]->[0], 
-      blessed($_[0])->new( @{ $_[0] }[ 1 .. $#{$_[0]} ] ) 
+      blessed_or_pkg($_[0])->new( @{ $_[0] }[ 1 .. $#{$_[0]} ] ) 
     )
     : $_[0]->[0]
 }
@@ -44,7 +61,7 @@ sub tail {
   wantarray ?
     (
       $_[0]->[-1],
-      blessed($_[0])->new( @{ $_[0] }[ 0 .. ($#{$_[0]} - 1) ] )
+      blessed_or_pkg($_[0])->new( @{ $_[0] }[ 0 .. ($#{$_[0]} - 1) ] )
     )
     : $_[0]->[-1]
 }
@@ -82,13 +99,13 @@ sub join {
 }
 
 sub map {
-  blessed($_[0])->new(
+  blessed_or_pkg($_[0])->new(
     CORE::map {; $_[1]->($_) } @{ $_[0] }
   )
 }
 
 sub grep {
-  blessed($_[0])->new(
+  blessed_or_pkg($_[0])->new(
     CORE::grep {; $_[1]->($_) } @{ $_[0] }
   )
 }
@@ -100,23 +117,23 @@ sub sort {
   } else {
     @sorted = CORE::sort @{ $_[0] }
   }
-  blessed($_[0])->new(@sorted)
+  blessed_or_pkg($_[0])->new(@sorted)
 }
 
 sub reverse {
-  blessed($_[0])->new(
+  blessed_or_pkg($_[0])->new(
     CORE::reverse @{ $_[0] }
   )
 }
 
 sub sliced {
-  blessed($_[0])->new(
+  blessed_or_pkg($_[0])->new(
     @{ $_[0] }[ @_[1 .. $#_] ]
   )
 }
 
 sub splice {
-  blessed($_[0])->new(
+  blessed_or_pkg($_[0])->new(
     CORE::splice @{ $_[0] }, $_[1], $_[2], @_[3 .. $#_]
   )
 }
@@ -142,7 +159,7 @@ sub mesh {
     confess "Expected ARRAY or compatible obj, got $_"
       unless (reftype $_ || '') eq 'ARRAY'
   }
-  blessed($_[0])->new(
+  blessed_or_pkg($_[0])->new(
     &List::MoreUtils::mesh( @_ )
   )
 # In case upstream ever changes, here's a pure-perl impl:
@@ -150,7 +167,7 @@ sub mesh {
 #  for my $item (@_) {
 #    $max_idx = $#$item if $max_idx < $#$item
 #  }
-#  blessed($_[0])->new(
+#  blessed_or_pkg($_[0])->new(
 #    map {;
 #      my $idx = $_; map {; $_->[$idx] } @_
 #    } 0 .. $max_idx
@@ -170,7 +187,7 @@ sub part {
   my ($self, $code) = @_;
   my @parts;
   CORE::push @{ $parts[ $code->($_) ] }, $_ for @$self;
-  my $cls = blessed $self;
+  my $cls = blessed_or_pkg($self);
   $cls->new(
     map {; $cls->new(defined $_ ? @$_ : () ) } @parts
   )
@@ -181,55 +198,55 @@ sub reduce {
 }
 
 sub items_after {
-  blessed($_[0])->new(
+  blessed_or_pkg($_[0])->new(
     &List::MoreUtils::after( $_[1], @{ $_[0] } )
   )
 }
 
 sub items_after_incl {
-  blessed($_[0])->new(
+  blessed_or_pkg($_[0])->new(
     &List::MoreUtils::after_incl( $_[1], @{ $_[0] } )
   )
 }
 
 sub items_before {
-  blessed($_[0])->new(
+  blessed_or_pkg($_[0])->new(
     &List::MoreUtils::before( $_[1], @{ $_[0] } )
   )
 }
 
 sub items_before_incl {
-  blessed($_[0])->new(
+  blessed_or_pkg($_[0])->new(
     &List::MoreUtils::before_incl( $_[1], @{ $_[0] } )
   )
 }
 
 sub shuffle {
-  blessed($_[0])->new(
+  blessed_or_pkg($_[0])->new(
     List::Util::shuffle( @{ $_[0] } )
   )
 }
 
 sub uniq {
-  blessed($_[0])->new(
+  blessed_or_pkg($_[0])->new(
     List::MoreUtils::uniq( @{ $_[0] } )
   )
 }
 
 sub sort_by {
-  blessed($_[0])->new(
+  blessed_or_pkg($_[0])->new(
     &List::UtilsBy::sort_by( $_[1], @{ $_[0] } )
   )
 }
 
 sub nsort_by {
-  blessed($_[0])->new(
+  blessed_or_pkg($_[0])->new(
     &List::UtilsBy::nsort_by( $_[1], @{ $_[0] } )
   )
 }
 
 sub uniq_by {
-  blessed($_[0])->new(
+  blessed_or_pkg($_[0])->new(
     &List::UtilsBy::uniq_by( $_[1], @{ $_[0] } )
   )
 }
@@ -302,6 +319,10 @@ Returns boolean true if the array is empty.
 
 Returns all elements in the array as a plain list.
 
+=head3 export
+
+Same as L</all>; included for consistency with hash-type objects.
+
 =head3 get
 
 Returns the array element corresponding to a specified index.
